==> gromacs_2025.4.orig.tar.gz: gromacs-2025.4/src/gromacs/hardware/device_management.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2012- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 *  \brief Defines the CPU stubs for the device management.
 *
 *  \author Anca Hamuraru <anca@streamcomputing.eu>
 *  \author Dimitrios Karkoulis <dimitris.karkoulis@gmail.com>
 *  \author Teemu Virolainen <teemu@streamcomputing.eu>
 *  \author Mark Abraham <mark.j.abraham@gmail.com>
 *  \author Szilárd Páll <pall.szilard@gmail.com>
 *  \author Artem Zhmurov <zhmurov@gmail.com>
 *
 * \ingroup module_hardware
 */
#include "gmxpre.h"

#include "device_management.h"

#include "gromacs/utility/fatalerror.h"

#include "device_information.h"

std::vector<std::unique_ptr<DeviceInformation>> findDevices()
{
    return {};
}

void setActiveDevice(const DeviceInformation& /* deviceInfo */) {}

void releaseDevice() {}

std::string getDeviceInformationString(const DeviceInformation& /* deviceInfo */)
{
    gmx_fatal(FARGS, "Device information requested in CPU build.");
}

bool isDeviceDetectionFunctional(std::string* /* errorMessage */)
{
    return false;
}

void doubleCheckGpuAwareMpiWillWork(const DeviceInformation& /* deviceInfo */) {}

==> gromacs-2026.0.tar.gz: gromacs-2026.0/src/gromacs/hardware/device_management.cpp <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2012- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 *  \brief Defines the CPU stubs for the device management.
 *
 *  \author Anca Hamuraru <anca@streamcomputing.eu>
 *  \author Dimitrios Karkoulis <dimitris.karkoulis@gmail.com>
 *  \author Teemu Virolainen <teemu@streamcomputing.eu>
 *  \author Mark Abraham <mark.j.abraham@gmail.com>
 *  \author Szilárd Páll <pall.szilard@gmail.com>
 *  \author Artem Zhmurov <zhmurov@gmail.com>
 *
 * \ingroup module_hardware
 */
#include "gmxpre.h"

#include "device_management.h"

#include "gromacs/utility/fatalerror.h"

#include "device_information.h"

std::vector<std::unique_ptr<DeviceInformation>> findDevices()
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
    return {};
}

void setActiveDevice(const DeviceInformation& /* deviceInfo */)
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
}

void releaseDevice()
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
}

std::string getDeviceInformationString(const DeviceInformation& /* deviceInfo */)
{
    gmx_fatal(FARGS, "Device information requested in CPU build.");
}

bool isDeviceDetectionFunctional(std::string* /* errorMessage */)
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
    return false;
}

void doubleCheckGpuAwareMpiWillWork(const DeviceInformation& /* deviceInfo */)
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
}

int maximumGridSize(const DeviceInformation& /* deviceInfo */)
{
    GMX_RELEASE_ASSERT(false, "Use of GPU specific function in CPU only build");
    return -1;
}
